==> volcano-model-v1beta1-5.12.1-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueBuilder.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class QueueBuilder extends io.fabric8.volcano.scheduling.v1beta1.QueueFluentImpl<io.fabric8.volcano.scheduling.v1beta1.QueueBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.volcano.scheduling.v1beta1.Queue,io.fabric8.volcano.scheduling.v1beta1.QueueBuilder>{
  public QueueBuilder() {
    this(false);
  }
  public QueueBuilder(java.lang.Boolean validationEnabled) {
    this(new Queue(), validationEnabled);
  }
  public QueueBuilder(io.fabric8.volcano.scheduling.v1beta1.QueueFluent<?> fluent) {
    this(fluent, false);
  }
  public QueueBuilder(io.fabric8.volcano.scheduling.v1beta1.QueueFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Queue(), validationEnabled);
  }
  public QueueBuilder(io.fabric8.volcano.scheduling.v1beta1.QueueFluent<?> fluent,io.fabric8.volcano.scheduling.v1beta1.Queue instance) {
    this(fluent, instance, false);
  }
  public QueueBuilder(io.fabric8.volcano.scheduling.v1beta1.QueueFluent<?> fluent,io.fabric8.volcano.scheduling.v1beta1.Queue instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public QueueBuilder(io.fabric8.volcano.scheduling.v1beta1.Queue instance) {
    this(instance,false);
  }
  public QueueBuilder(io.fabric8.volcano.scheduling.v1beta1.Queue instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.volcano.scheduling.v1beta1.QueueFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.volcano.scheduling.v1beta1.Queue build() {
    Queue buildable = new Queue(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QueueBuilder that = (QueueBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> volcano-model-v1beta1-6.3.0-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueBuilder.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class QueueBuilder extends QueueFluentImpl<QueueBuilder> implements VisitableBuilder<Queue,QueueBuilder>{
  public QueueBuilder() {
    this(false);
  }
  public QueueBuilder(Boolean validationEnabled) {
    this(new Queue(), validationEnabled);
  }
  public QueueBuilder(QueueFluent<?> fluent) {
    this(fluent, false);
  }
  public QueueBuilder(QueueFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Queue(), validationEnabled);
  }
  public QueueBuilder(QueueFluent<?> fluent,Queue instance) {
    this(fluent, instance, false);
  }
  public QueueBuilder(QueueFluent<?> fluent,Queue instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public QueueBuilder(Queue instance) {
    this(instance,false);
  }
  public QueueBuilder(Queue instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  QueueFluent<?> fluent;
  Boolean validationEnabled;
  public Queue build() {
    Queue buildable = new Queue(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
